# How to Setup tRPC API Server & Client with Next.js and Prisma

This article will teach you how to set up a tRPC API server and client with Next.js, PostgreSQL, React Query, Prisma, Redis, and Docker-compose.

![How to Setup tRPC API Server & Client with Next.js and Prisma](https://codevoweb.com/wp-content/uploads/2022/08/How-to-Setup-tRPC-API-Server-Client-with-Next.js-and-Prisma.webp)

## Topics Covered

- Setup Next.js as a Monolithic Repository
- Setup Redis and PostgreSQL with Docker
    - Adding the Docker-compose Configurations
    - Adding the PostgreSQL Docker Image Credentials
    - Starting the Redis and PostgreSQL Docker Containers
- Setup Prisma with PostgreSQL
    - Creating the Database Models with Prisma
    - Migrating the Prisma Schema to the PostgreSQL Database
- Creating the Next.js tRPC Server
    - Installing the tRPC dependencies
    - Connecting to the Redis and PostgreSQL Containers
    - Creating the tRPC Context and Routes
    - Adding the tRPC Routes to the Next.js API Router
    - Testing the Next.js tRPC Server
- Setup tailwindCss in the tRPC Next.js Project
- Creating the Next.js tRPC Client

Read the entire article here: [https://codevoweb.com/setup-trpc-api-server-client-with-nextjs-and-prisma](https://codevoweb.com/setup-trpc-api-server-client-with-nextjs-and-prisma)

Articles in this series:

### 1. How to Setup tRPC API Server & Client with Next.js and Prisma

[How to Setup tRPC API Server & Client with Next.js and Prisma](https://codevoweb.com/setup-trpc-api-server-client-with-nextjs-and-prisma)

### 2. Build tRPC API with Next.js & PostgreSQL: Access & Refresh Tokens

[Build tRPC API with Next.js & PostgreSQL: Access & Refresh Tokens](https://codevoweb.com/trpc-api-with-nextjs-postgresql-access-refresh-tokens)

### 3. Full-Stack Next.js tRPC App: User Registration & Login Example

[Full-Stack Next.js tRPC App: User Registration & Login Example](https://codevoweb.com/fullstack-nextjs-trpc-app-user-registration-login-example/)

### 4. Build a tRPC CRUD API Example with Next.js

[Build a tRPC CRUD API Example with Next.js](https://codevoweb.com/build-a-trpc-crud-api-example-with-next-js/)
